package com.lantone.message.client;

import com.lantone.common.api.CommonResult;
import com.lantone.common.dto.AbnormalLogDTO;
import com.lantone.common.dto.LoginLogDTO;
import com.lantone.common.dto.OperationLogDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;

/**
 * @Description: 权限中心远程调用
 * @author: rengb
 * @time: 2021/1/5 18:27
 */
@FeignClient("security-center")
public interface SecurityService {

    @PostMapping("/logManage/addLoginLog")
    CommonResult addLoginLog(LoginLogDTO loginLog);

    @PostMapping("/logManage/addOperLog")
    CommonResult addOperLog(OperationLogDTO operationLog);

    @PostMapping("/logManage/addOperErrorLog")
    CommonResult addOperErrorLog(AbnormalLogDTO abnormalLogDTO);

    @PostMapping("/dictionaryManage/initDicMap")
    CommonResult initDicMap();

    @PostMapping("/hospitalSetManage/initHospitalSetMap")
    CommonResult initHospitalSetMap();

    @PostMapping("/funcManage/initResourceRolesMap")
    CommonResult initResourceRolesMap();

    @PostMapping("/dataAuthManage/initUserDataAuth")
    CommonResult initUserDataAuth();

}